<?php
/**
 * Plugin Name: PA Knowledge Base
 * Plugin URI: http://20script.ir
 * Description: Knowledge base WordPress plugin
 * Author: PressApps Team
 * Version: 1.1.2
 */

/*-----------------------------------------------------------------------------------*/
/* Return option page data */
/*-----------------------------------------------------------------------------------*/

$knowledgebase_settings = get_option( 'pressapps_knowledgebase_options' );

define('PRESSAPPS_KNOWLEDGEBASE_PLUGIN_DIR',dirname(__FILE__));

class PRESSAPPS_KNOWLEDGEBASE{
    
    function __construct() {

        global $knowledgebase_settings;

        include_once 'function.php';
        include_once 'include/loop.php';
        include_once 'include/template.php';
        include_once 'add_action.php';
        include_once 'add_filter.php';
        include_once 'admin-reorder.php';
        include_once 'admin-page.php';
        include_once 'widget/knowledgebase-search.php';
        include_once 'widget/knowledgebase-latest.php';

        load_plugin_textdomain('pressapps', false, basename(dirname(__FILE__)).'/lang' );
        
        add_action('init',array($this,'init'));
        add_action('admin_init',array($this,'admin_init'));
        add_action('template_redirect' ,array($this,'template_redirect'));
        add_action( 'wp_head', 'print_knowledgebase_css' );
        // Add the users custom CSS if they wish to add any.
        if ( $knowledgebase_settings['custom-css'] ) {
            add_action( 'wp_head', 'print_knowledgebase_custom_css' );
        }
        add_action('widgets_init' ,'widgets_init');

        function widgets_init(){
            register_widget('LATEST_KNOWLEDGEBASE');
            register_widget('SEARCH_KNOWLEDGEBASE');
        }

    }
    
    function admin_init(){
        global $pagenow,$knowledgebase_settings;
        
        if(isset($_GET['page']) && isset($_GET['settings-updated'])){
            if($_GET['page'] == 'knowledgebase-options' && $_GET['settings-updated'] == 'true'){
                flush_rewrite_rules(TRUE);
            }
         }
         
        if($knowledgebase_settings['reorder'] != 1)
            return ;
        
        if( $pagenow == 'edit.php') {
            if ( isset($_GET['post_type']) && 'knowledgebase' == $_GET['post_type'] ) {
                wp_register_style('pressapps_order-admin-styles'       , plugin_dir_url(__FILE__) . 'css/admin.css');
    
                wp_register_script('pressapps_order-update-order'       , plugin_dir_url(__FILE__) . 'js/order-posts.js');


                wp_enqueue_script('jquery-ui-sortable');
                wp_enqueue_script('pressapps_order-update-order');
                wp_enqueue_style('pressapps_order-admin-styles');
                
                add_filter( 'pre_get_posts', 'pressapps_knowledgebase_order_reorder_list' );
                
            }
        } elseif( $pagenow == 'edit-tags.php' ) {
            if ( isset($_GET['post_type']) && 'knowledgebase' == $_GET['post_type'] ) {
                wp_register_style('pressapps_order-admin-styles'       , plugin_dir_url(__FILE__) . 'css/admin.css');
    
                wp_register_script('pressapps_order-update-order'       , plugin_dir_url(__FILE__) . 'js/order-taxonomies.js');
    
                wp_enqueue_script('jquery-ui-sortable');
                wp_enqueue_script('pressapps_order-update-order');
                wp_enqueue_style('pressapps_order-admin-styles');
                
                add_filter( 'get_terms_orderby', 'pressapps_knowledgebase_order_reorder_taxonomies_list', 10, 2 );
            }
        } 
        /**
         * 
         * @note this section is only executed if the condition on line 62 is true
         * so better place to write logic will be above that condition
         */
    }
    function init(){
        
        global $knowledgebase_settings;

        register_post_type( 'knowledgebase',array(
            'description'           => __('Knowledge Base','pressapps'),
            'labels'                => array(
                'name'                  => __('Knowledge Base'                     ,'pressapps'),
                'singular_name'         => __('Knowledge Base'                      ,'pressapps'),
                'add_new'               => __('Add Knowledge Base'                  ,'pressapps'),  
                'add_new_item'          => __('Add New Knowledge Base'              ,'pressapps'),  
                'edit_item'             => __('Edit Knowledge Base'                 ,'pressapps'),  
                'new_item'              => __('New Knowledge Base'                  ,'pressapps'),  
                'view_item'             => __('View Knowledge Base'                ,'pressapps'),  
                'search_items'          => __('Search Knowledge Base'              ,'pressapps'),  
                'not_found'             => __('No Knowledge Base found'            ,'pressapps'),  
                'not_found_in_trash'    => __('No Knowledge Base found in Trash'   ,'pressapps'),
                'all_items'             => __('All Knowledge Base'                 ,'pressapps'),
            ),
            'public'                => true,
            'menu_position'         => 5,
            'rewrite'               => array(
                'slug'       => $knowledgebase_settings['knowledgebase_slug'],
                'with_front' => false,
            ),
            'supports'              => array('title','editor','author','comments','page-attributes','thumbnail'),
            'public'                => true,
            'show_ui'               => true,
            'publicly_queryable'    => true,
            'has_archive'           => true,
            'exclude_from_search'   => false
        ));

        register_taxonomy( 'knowledgebase_category',array( 'knowledgebase' ),array( 
            'hierarchical'  => false,
            'labels'        => array(
                'name'              => __( 'Categories'             ,'pressapps'),
                'singular_name'     => __( 'Category'               ,'pressapps'),
                'search_items'      => __( 'Search Categories'      ,'pressapps'),
                'all_items'         => __( 'All Categories'         ,'pressapps'),
                'parent_item'       => __( 'Parent Category'        ,'pressapps'),
                'parent_item_colon' => __( 'Parent Category:'       ,'pressapps'),
                'edit_item'         => __( 'Edit Category'          ,'pressapps'),
                'update_item'       => __( 'Update Category'        ,'pressapps'),
                'add_new_item'      => __( 'Add New Category'       ,'pressapps'),
                'new_item_name'     => __( 'New Category Name'      ,'pressapps'),
                'popular_items'     => NULL,
                'menu_name'         => __( 'Categories'             ,'pressapps') 
            ),
            'show_ui'       => true,
            'public'        => true,
            'query_var'     => true,
            'hierarchical'  => true,
            'rewrite'       => array( 'slug' => $knowledgebase_settings['knowledgebase_cat_slug'] )
        ));
        
        register_taxonomy( 'knowledgebase_tags',array( 'knowledgebase' ),array( 
            'hierarchical'  => false,
            'labels'        => array(
                'name'              => __( 'Tags'              ,'pressapps'),
                'singular_name'     => __( 'Tag'               ,'pressapps'),
                'search_items'      => __( 'Search Tags'       ,'pressapps'),
                'all_items'         => __( 'All Tags'          ,'pressapps'),
                'parent_item'       => __( 'Parent Tag'        ,'pressapps'),
                'parent_item_colon' => __( 'Parent Tag:'       ,'pressapps'),
                'edit_item'         => __( 'Edit Tag'          ,'pressapps'),
                'update_item'       => __( 'Update Tag'        ,'pressapps'),
                'add_new_item'      => __( 'Add New Tag'       ,'pressapps'),
                'new_item_name'     => __( 'New Tag Name'      ,'pressapps'),
                'popular_items'     => NULL,
                'menu_name'         => __( 'Tags'              ,'pressapps') 
            ),
            'show_ui'       => true,
            'public'        => true,
            'query_var'     => true,
            'hierarchical'  => false,
            'rewrite'       => array( 'slug' => 'knowledgebase_tags' )
        ));
        
        wp_register_style('pressapps_knowledgebase_default'        , plugins_url('/css/default.css', __FILE__));
        wp_register_script('pressapps_knowledgebase_tooltip'       , plugins_url('/js/tooltip.min.js'         , __FILE__)      ,array('jquery'));
        wp_register_script('pressapps_knowledgebase_custom'        , plugins_url('/js/custom.js'         , __FILE__)      ,array('jquery'));

        wp_enqueue_style('pressapps_knowledgebase_default');
        wp_enqueue_script('pressapps_knowledgebase_tooltip');
        wp_enqueue_script('pressapps_knowledgebase_custom');
        
        add_filter('pre_get_posts',array($this,'pre_get_posts'));
       
    }

    function pre_get_posts($query){
         if ( is_tax('knowledgebase_category') || is_tax('knowledgebase_tags'))
            $query->set('posts_per_archive_page', -1);
         return $query;
    }
    
    function template_redirect(){
        global $wp_query,$pakb_query,$post,$knowledgebase_settings;
        $pakb_query = $wp_query;
       
        if(
                is_post_type_archive('knowledgebase') || is_singular('knowledgebase') 
             || is_tax('knowledgebase_category')      || is_tax('knowledgebase_tags') 
             || is_page($knowledgebase_settings['knowledgebase_page'])
             || (is_search() && (isset($_REQUEST['post_type'])?($_REQUEST['post_type']=='knowledgebase'):FALSE)   )
                
          ){
            
            $overridekb = FALSE;
            $kb_page    = get_post($knowledgebase_settings['knowledgebase_page']);
            
            if(!empty($kb_page)){
                if($knowledgebase_settings['knowledgebase_slug'] == $kb_page->post_name){
                    $overridekb = TRUE;
                }
            }
                
            if((is_post_type_archive('knowledgebase') && !$overridekb) || is_search()){
                
                if(is_search()){
                    $post   = new WP_Post((object)pakb_get_dummy_post_data(array(
                        'post_content'          => pakb_load_file(pakb_get_template_files('search')),
                        'post_title'            => sprintf(__('Search Result for "%s"','pressapps'),$_REQUEST['s']),
                    )));
                }else{
                    
                    $post   = new WP_Post((object)pakb_get_dummy_post_data(array(
                        'post_content'          => pakb_load_file(pakb_get_template_files('archive')),
                        'post_title'            => __('KB Archive'     ,'pressapps'),
                    )));
                }
                
                /**
                 * @todo this is redundant Code we need to get this updated with 1 function call like pakb_override_is_var
                 */
                $wp_query->queried_object       = $post;
                $wp_query->queried_object_id    = (int) $post->ID;
                $wp_query->posts                = array($post);
                $wp_query->post                 = $post;
                $wp_query->post_count           = 1;
                
                

      
            }elseif(is_tax('knowledgebase_category')){
                
                pakb_process_cat();
                
                if(pakb_has_sub_cat()){
                    
                    $post   = new WP_Post((object)pakb_get_dummy_post_data(array(
                        'ID'                    => $knowledgebase_settings['knowledgebase_page'],
                        'post_content'          => pakb_load_file(pakb_get_template_files('knowledgebase')),
                        'post_title'            => $knowledgebase_settings['knowledgebase_title'],
                    )));
                    
                    add_filter('page_template',array($this,'page_template'));
                    
                }else{
                    $post   = new WP_Post((object)pakb_get_dummy_post_data(array(
                        'post_content'          => pakb_load_file(pakb_get_template_files('archive')),
                        'post_title'            => $knowledgebase_settings['knowledgebase_title'],
                    )));
                }
                
                $wp_query->queried_object       = $post;
                $wp_query->queried_object_id    = (int) $post->ID;
                $wp_query->posts                = array($post);
                $wp_query->post                 = $post;
                $wp_query->post_count           = 1;
                
               
            }elseif(is_tax('knowledgebase_tags')){
                
                $post   = new WP_Post((object)pakb_get_dummy_post_data(array(
                    'post_content'          => pakb_load_file(pakb_get_template_files('archive')),
                    'post_title'            => $knowledgebase_settings['knowledgebase_title'],
                )));
               
                $wp_query->queried_object       = $post;
                $wp_query->queried_object_id    = (int) $post->ID;
                $wp_query->posts                = array($post);
                $wp_query->post                 = $post;
                $wp_query->post_count           = 1;
                
               
            }elseif(is_singular('knowledgebase')){
                
                $post   = new WP_Post((object)pakb_get_dummy_post_data(array(
                    'ID'                    => $wp_query->post->ID,
                    'post_content'          => pakb_load_file(pakb_get_template_files('single')),
                    'post_title'            => $knowledgebase_settings['knowledgebase_title'],
                )));
                
                $wp_query->queried_object       = $post;
                $wp_query->queried_object_id    = (int) $post->ID;
                $wp_query->posts        = array($post);
                $wp_query->post         = $post;
                $wp_query->post_count   = 1;
                
                
            }elseif(is_page($knowledgebase_settings['knowledgebase_page']) || $overridekb){
                pakb_process_kbpage();
                
                $post   = new WP_Post((object)pakb_get_dummy_post_data(array(
                    'ID'                    => $wp_query->post->ID,
                    'post_content'          => pakb_load_file(pakb_get_template_files('knowledgebase')),
                    'post_title'            => $knowledgebase_settings['knowledgebase_title'],
                )));
                
                $wp_query->queried_object       = $post;
                $wp_query->queried_object_id    = (int) $post->ID;
                $wp_query->posts        = array($post);
                $wp_query->post         = $post;
                $wp_query->post_count   = 1;

                
                add_filter('page_template',array($this,'page_template'));
            }
            
            //remove_filter( 'the_content', 'wpautop' );
            pakb_override_is_var();
        }
        
    }

    function page_template($template){
        
        global $knowledgebase_settings;
        
        if(!isset($knowledgebase_settings['knowledgebase_page']))
            return $template;

        $page_id = $knowledgebase_settings['knowledgebase_page'];
        
        $template_file = get_post_meta($page_id,'_wp_page_template',TRUE);
        
        if(empty($template_file))
            return $template;
        
        $new_template = get_template_directory() . "/{$template_file}";
        
        return (file_exists($new_template)?$new_template:$template);
    }
}

$pressapps_knowledgebase = new PRESSAPPS_KNOWLEDGEBASE();

